@@ -13,11 +13,19 @@ from autots.evaluator.auto_ts import AutoTS
 from autots.tools.transform import GeneralTransformer
 from autots.tools.shaping import long_to_wide
 
-__version__ = '0.2.2'
+__version__ = '0.2.3'
 
 
-__all__ = ['load_daily','load_monthly', 'load_yearly', 'load_hourly', 'load_weekly',
-           'AutoTS', 'GeneralTransformer', 'long_to_wide']
+__all__ = [
+    'load_daily',
+    'load_monthly',
+    'load_yearly',
+    'load_hourly',
+    'load_weekly',
+    'AutoTS',
+    'GeneralTransformer',
+    'long_to_wide',
+]
 
 # import logging
 # logger = logging.getLogger(__name__)
